@@ -2,16 +2,6 @@ from PyObjCTools.TestSupport import *
 from CFNetwork import *
 import os
 
-try:
-    long
-except NameError:
-    long = int
-
-try:
-    unicode
-except NameError:
-    unicode = str
-
 SCRIPT="""
 function FindProxyForURL(url, host) {
    if (shExpMatch(host, "*.apple.com")) {
@@ -62,7 +52,7 @@ class TestCFProxySupport (TestCase):
         rl = CFRunLoopGetCurrent()
         CFRunLoopAddSource(rl, rls,  kCFRunLoopCommonModes)
 
-        CFRunLoopRunInMode(kCFRunLoopDefaultMode, 1.0, True)
+        CFRunLoopRunInMode(kCFRunLoopDefaultMode, 1.0, False)
 
         CFRunLoopRemoveSource(rl, rls,  kCFRunLoopCommonModes)
 
